==> steenzout.serialization.json-1.0.0.tar.gz: steenzout.serialization.json-1.0.0/README.md <==
# serialization.json

[![pypi](https://img.shields.io/pypi/v/steenzout.serialization-json.svg)](https://pypi.python.org/pypi/steenzout.serialization.json/)
[![Build Status](https://travis-ci.org/steenzout/python-serialization-json.svg?branch=master)](https://travis-ci.org/steenzout/python-serialization-json)
[![Code Health](https://landscape.io/github/steenzout/python-serialization-json/master/landscape.svg?style=flat)](https://landscape.io/github/steenzout/python-serialization-json/master)
[![Coverage Status](https://coveralls.io/repos/github/steenzout/python-serialization-json/badge.svg?branch=master)](https://coveralls.io/r/steenzout/python-serialization-json)
[![Requirements Status](https://requires.io/github/steenzout/python-serialization-json/requirements.svg?branch=master)](https://requires.io/github/steenzout/python-serialization-json/requirements/?branch=master)
[![Documentation Status](https://readthedocs.org/projects/python-steenzout-serialization-json/badge/?version=latest)](http://python-steenzout-serialization-json.readthedocs.io/en/latest/?badge=latest)

[![License](https://img.shields.io/badge/license-Apache%20License%202.0-blue.svg?style=flat)][license]
[![Project Stats](https://www.openhub.net/p/python-steenzout-serialization-json/widgets/project_thin_badge.gif)](https://www.openhub.net/p/python-steenzout-serialization-json/)

Steenzout JSON serialization package.


## Links

- [python > 2.7 > json](https://docs.python.org/2.7/library/json.html)
- [stackoverflow > How to convert JSON data into a Python serialization.json](http://stackoverflow.com/questions/6578986/how-to-convert-json-data-into-a-python-serialization.json)
- [stackoverfliw > How to make simplejson serializable class](http://stackoverflow.com/questions/4821940/how-to-make-simplejson-serializable-class)
- [stackoverflow > JSON datetime between Python and JavaScript](http://stackoverflow.com/questions/455580/json-datetime-between-python-and-javascript)
- [stackoverflow > Serializing a Python namedtuple to json](http://stackoverflow.com/questions/5906831/serializing-a-python-namedtuple-to-json)
- [Python Tips > Storing and Loading Data with JSON](https://pythontips.com/2013/08/08/storing-and-loading-data-with-json/)


[license]:  https://raw.githubusercontent.com/steenzout/python-serialization-json/master/LICENSE   "License"

==> steenzout.serialization.json-1.0.4.tar.gz: steenzout.serialization.json-1.0.4/README.md <==
# serialization.json

[![pypi](https://img.shields.io/pypi/v/steenzout.serialization-json.svg)](https://pypi.python.org/pypi/steenzout.serialization.json/)
[![Build Status](https://travis-ci.org/steenzout/python-serialization-json.svg?branch=master)](https://travis-ci.org/steenzout/python-serialization-json)
[![Code Health](https://landscape.io/github/steenzout/python-serialization-json/master/landscape.svg?style=flat)](https://landscape.io/github/steenzout/python-serialization-json/master)
[![Coverage Status](https://coveralls.io/repos/github/steenzout/python-serialization-json/badge.svg?branch=master)](https://coveralls.io/r/steenzout/python-serialization-json)
[![Requirements Status](https://requires.io/github/steenzout/python-serialization-json/requirements.svg?branch=master)](https://requires.io/github/steenzout/python-serialization-json/requirements/?branch=master)
[![Documentation Status](https://readthedocs.org/projects/python-steenzout-serialization-json/badge/?version=master)](http://python-steenzout-serialization-json.readthedocs.io/en/latest/?badge=master)

[![License](https://img.shields.io/badge/license-Apache%20License%202.0-blue.svg?style=flat)][license]
[![Project Stats](https://www.openhub.net/p/python-steenzout-serialization-json/widgets/project_thin_badge.gif)](https://www.openhub.net/p/python-steenzout-serialization-json/)

Steenzout JSON serialization package.


## Links

- [python > 2.7 > json](https://docs.python.org/2.7/library/json.html)
- [stackoverflow > How to convert JSON data into a Python serialization.json](http://stackoverflow.com/questions/6578986/how-to-convert-json-data-into-a-python-serialization.json)
- [stackoverfliw > How to make simplejson serializable class](http://stackoverflow.com/questions/4821940/how-to-make-simplejson-serializable-class)
- [stackoverflow > JSON datetime between Python and JavaScript](http://stackoverflow.com/questions/455580/json-datetime-between-python-and-javascript)
- [stackoverflow > Serializing a Python namedtuple to json](http://stackoverflow.com/questions/5906831/serializing-a-python-namedtuple-to-json)
- [Python Tips > Storing and Loading Data with JSON](https://pythontips.com/2013/08/08/storing-and-loading-data-with-json/)


[license]:  https://raw.githubusercontent.com/steenzout/python-serialization-json/master/LICENSE   "License"
